# gpioc
This library can be used to control gpio by Python and C.

Reading and writing gpio registers through `/dev/mem`

## support chips
- Allwinner H616


# example code
- the pythone example code is in `./example-pythone` folder 
- the c example code is in `./example-c` folder 
